==> moodle_1.3.1.orig.tar.gz: moodle/lang/fi/glossary.php <==
<?PHP // $Id: glossary.php,v 1.5 2004/04/14 18:10:33 paca70 Exp $ 
      // glossary.php - created with Moodle 1.3 development (2004032800)


$string['addcomment'] = 'Lis kommentti';
$string['addentry'] = 'Lis uusi tietue';
$string['addingcomment'] = 'Lis kommentti';
$string['aliases'] = 'Avainsana(t)';
$string['allcategories'] = 'Kaikki kategoriat';
$string['allentries'] = 'Kaikki';
$string['allowcomments'] = 'Salli tietueiden kommentit ';
$string['allowduplicatedentries'] = 'Pllekkiset tietueet sallitaan';
$string['allowratings'] = 'Salli tietueiden arviointi';
$string['answer'] = 'Vastaus';
$string['approve'] = 'Vahvista';
$string['areyousuredelete'] = 'Haluatko todella poistaa tmn tietueen?';
$string['areyousuredeletecomment'] = 'Haluatko todella poistaa tmn kommentin?';
$string['areyousureexport'] = 'Haluatko todella vied tmn tietueen ->';
$string['ascending'] = '(nouseva)';
$string['attachment'] = 'Liite';
$string['authorview'] = 'Selaa kirjoittajan mukaan';
$string['back'] = 'Takaisin';
$string['cantinsertcat'] = 'Kategoriaa ei voi list';
$string['cantinsertrec'] = 'Tietuetta ei voi list';
$string['cantinsertrel'] = 'Relaatiota kategoriaan ei voi list';
$string['casesensitive'] = 'Tmn tietueen kirjainkoko on merkityksellinen (&quot;case sensitive&quot;)';
$string['categories'] = 'Kategoriat';
$string['category'] = 'Kategoria';
$string['categorydeleted'] = 'Kategoria poistettu';
$string['categoryview'] = 'Selaa kategorioiden mukaan';
$string['cnfallowcomments'] = 'Mrit, sallitaanko kommentit sanaston tietueisiin oletuksena';
$string['cnfallowdupentries'] = 'Mrit, sallitaanko pllekkisyydet sanastossa oletuksena';
$string['cnfapprovalstatus'] = 'Mrit oletustila opiskelijoiden lhettmille tietueille.';
$string['cnfcasesensitive'] = 'Onko oletuksena tietueen kirjainkoko merkityksellinen (&quot;case sensitive&quot;), kun tietue linkitetn. ';
$string['cnfdefaulthook'] = 'Valitse oletuskokoelma nytettvksi, kun sanastoon tutustutaan ensimmist kertaa.';
$string['cnfdefaultmode'] = 'Valitse oletuskehys, kun sanastoon tutustutaan ensimmist kertaa.';
$string['cnffullmatch'] = 'Kun tietuetta linkitetn, onko oletuksena kohdetekstin kirjainkoko merkityksellinen?';
$string['cnflinkentry'] = 'Linkitetnk tietue automaattisesti oletuksena?';
$string['cnflinkglossaries'] = 'Linkitetnk sanasto automaattisesti oletuksena?';
$string['cnfrelatedview'] = 'Valitse nytttapa automaattiselle linkittmiselle ja tietueen katsomiselle.';
$string['cnfshowgroup'] = 'Nytetnk ryhmerotin?';
$string['cnfsortkey'] = 'Valitse oletuslajitteluavain.';
$string['cnfsortorder'] = 'Valitse oletuslajittelujrjestys.';
$string['cnfstudentcanpost'] = 'Voiko opiskelija list tietueita oletuksena?';
$string['comment'] = 'Kommentti';
$string['commentdeleted'] = 'Kommentti poistettu';
$string['comments'] = 'kommentit';
$string['commentson'] = 'Kommentit thn';
$string['commentupdated'] = 'Kommentti on pivitetty.';
$string['concept'] = 'Ksite';
$string['concepts'] = 'Ksitteet';
$string['currentglossary'] = 'Nykyinen sanasto';
$string['dateview'] = 'Selaa pivmrien mukaan';
$string['defaultapproval'] = 'Oletustila hyvksymiselle';
$string['definition'] = 'Mritelm';
$string['definitions'] = 'Mritelmt';
$string['deleteentry'] = 'Poista tietue';
$string['deletingcomment'] = 'Poistetaan kommenttia';
$string['deletingnoneemptycategory'] = 'Tmn kategorian poistaminen ei tuhoa sen sisltmi tietueita - ne merkitn kategorisoimattomiksi.';
$string['descending'] = '(laskeva)';
$string['destination'] = 'Mrnp';
$string['displayformat'] = 'Sanaston tietueiden selaustapa';
$string['displayformat2'] = 'Kaikki kirjoittajatietoineen';
$string['displayformat3'] = 'Tietosanakirja';
$string['displayformat4'] = 'FAQ';
$string['displayformat5'] = 'Kaikki ilman kirjoittajatietoja';
$string['displayformat6'] = 'Kohdelista';
$string['displayformatcontinuous'] = 'Jatkuva ilman kirjoittajatietoja';
$string['displayformatdefault'] = 'Yksinkertainen, sanakirjan tyyli';
$string['displayformats'] = 'Sanaston tietueiden selaustavat';
$string['duplicateentry'] = 'Pllekkinen tietue';
$string['editcategories'] = 'Muokkaa kategorioita';
$string['editentry'] = 'Muokkaa tietuetta';
$string['editingcomment'] = 'Muokkaa kommenttia';
$string['entbypage'] = 'Nytettvien tietueiden mr sivua kohti';
$string['entries'] = 'Tietueet';
$string['entrieswithoutcategory'] = 'Kategorisoimattomat tietueet';
$string['entry'] = 'Tietue';
$string['entryalreadyexist'] = 'Tietue on jo olemassa';
$string['entryapproved'] = 'Tm tietue on hyvksytty';
$string['entrydeleted'] = 'Tietue poistettu';
$string['entryexported'] = 'Tietueen vienti onnistui';
$string['entryishidden'] = '(tm tietue on tll hetkell piilotettuna)';
$string['entryusedynalink'] = 'Tm tietue pitisi linkitty automaattisesti';
$string['explainaddentry'] = 'Lis uusi tietue sanastoon.<br />Ksite ja mritelm ovat pakollisia kentti.';
$string['explainall'] = 'Nyt kaikki tietueet yhdell sivulla';
$string['explainalphabet'] = 'Selaa sanastoa tmn hakemiston avulla.';
$string['explainexport'] = 'Vientitiedosto on luotu.<br />Lataa se ja silyt sit huolella. Voit tuoda sen milloin tahansa tlle tai mille tahansa muulle kurssille.';
$string['explainimport'] = 'Mrit tuontitiedosto ja tuonnin asetukset.';
$string['explainspecial'] = 'Nytt tietueet, jotka eivt ala kirjaimella';
$string['exportedentry'] = 'Viety tietue';
$string['exportedfile'] = 'Vientitiedosto';
$string['exportentries'] = 'Vie tietueet';
$string['exportglossary'] = 'Vie sanasto';
$string['exporttomainglossary'] = 'Vie psanastoon';
$string['filetoimport'] = 'Tuontitiedosto';
$string['fillfields'] = 'Ksite ja mritelm ovat pakollisia kentti.';
$string['filtername'] = 'Sanaston automaattinen linkitys';
$string['fullmatch'] = 'Hae vain kokonaisia sanoja';
$string['glossarytype'] = 'Sanaston tyyppi';
$string['glosssaryexported'] = 'Sanasto viety.';
$string['importcategories'] = 'Tuo kategorioita';
$string['importedcategories'] = 'Tuodut kategoriat';
$string['importedentries'] = 'Tuodut tietueet';
$string['importentries'] = 'Tuo tietueita';
$string['isglobal'] = 'Globaali sanasto?';
$string['linkcategory'] = 'Linkit tm kategoria automaattisesti';
$string['mainglossary'] = 'Psanasto';
$string['maxtimehaspassed'] = 'Tmn kommentin ($a) sallittu muokkausaika ylittynyt.';
$string['modulename'] = 'Sanasto';
$string['modulenameplural'] = 'Sanastot';
$string['newentries'] = 'Uudet sanaston tietueet';
$string['newglossary'] = 'Uusi sanasto';
$string['newglossarycreated'] = 'Uusi sanasto luotu.';
$string['newglossaryentries'] = 'Uudet sanaston tietueet:';
$string['nocomment'] = 'Kommentteja ei lytynyt';
$string['nocomments'] = '(Kommentteja ei lytynyt tlle tietueelle)';
$string['noconceptfound'] = 'Ksitett tai mritelm ei lytynyt.';
$string['noentries'] = 'Tst osiossa ei lytynyt tietueita';
$string['noentry'] = 'Hakusanoja ei lytynyt.';
$string['notcategorised'] = 'Kategorisoimaton';
$string['numberofentries'] = 'Hakusanojen lukumr';
$string['onebyline'] = '(yksi rivi kohden)';
$string['printerfriendly'] = 'Tulostukseen soveltuva versio';
$string['question'] = 'Kysymys';
$string['rate'] = 'Arvo';
$string['rating'] = 'Arvio';
$string['ratingeveryone'] = 'Kaikki voivat arvioida tietueita';
$string['ratingno'] = 'Ei arvioita';
$string['ratingonlyteachers'] = 'Vain $a voi arvioida tietueita';
$string['ratings'] = 'Arviot';
$string['ratingssaved'] = 'Arviot tallennettu';
$string['ratingsuse'] = 'Kyt arvioita';
$string['ratingtime'] = 'Rajoita tietueiden arvointi niden pivmrien vlille:';
$string['rejectedentries'] = 'Hyltyt tietueet';
$string['rejectionrpt'] = 'Hylkysraportti';
$string['searchindefinition'] = 'Vapaatekstihaku';
$string['secondaryglossary'] = 'Toissijainen sanasto';
$string['sendinratings'] = 'Lhet viimeisimmt arvioni';
$string['showall'] = 'Nyt linkki \'Kaikki\'';
$string['showalphabet'] = 'Nyt akkosittain';
$string['showspecial'] = 'Nyt linkki \'Erikoiset\'';
$string['sortby'] = 'Lajittele';
$string['sortbycreation'] = 'Luontipivyksen mukaan';
$string['sortbylastupdate'] = 'Viimeisen pivityksen mukaan';
$string['sortchronogically'] = 'Lajittele kronologisesti';
$string['special'] = 'Erikoiset';
$string['standardview'] = 'Selaa aakkosjrjestyksess';
$string['studentcanpost'] = 'Opiskelijat voivat list tietueita';
$string['totalentries'] = 'Hakusanojen kokonaismr';
$string['usedynalink'] = 'Linkit sanaston tietueet automaattisesti';
$string['waitingapproval'] = 'Odotetaan hyvksynt';
$string['warningstudentcapost'] = '(Soveltuu vain jos sanasto ei ole psanasto)';
$string['writtenby'] = 'kirjoittanut';
$string['youarenottheauthor'] = 'Et ole kommentin kirjoittaja, joten et voi muokata sit.';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fi/glossary.php <==
<?PHP // $Id$ 
      // glossary.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['addcomment'] = 'Lis kommentti';
$string['addentry'] = 'Lis uusi tietue';
$string['addingcomment'] = 'Lis kommentti';
$string['aliases'] = 'Avainsana(t)';
$string['allcategories'] = 'Kaikki kategoriat';
$string['allentries'] = 'Kaikki';
$string['allowcomments'] = 'Salli tietueiden kommentit ';
$string['allowduplicatedentries'] = 'Pllekkiset tietueet sallitaan';
$string['allowratings'] = 'Salli tietueiden arviointi';
$string['answer'] = 'Vastaus';
$string['approve'] = 'Vahvista';
$string['areyousuredelete'] = 'Haluatko todella poistaa tmn tietueen?';
$string['areyousuredeletecomment'] = 'Haluatko todella poistaa tmn kommentin?';
$string['areyousureexport'] = 'Haluatko todella vied tmn tietueen ->';
$string['ascending'] = '(nouseva)';
$string['attachment'] = 'Liite';
$string['authorview'] = 'Selaa kirjoittajan mukaan';
$string['back'] = 'Takaisin';
$string['cantinsertcat'] = 'Kategoriaa ei voi list';
$string['cantinsertrec'] = 'Tietuetta ei voi list';
$string['cantinsertrel'] = 'Relaatiota kategoriaan ei voi list';
$string['casesensitive'] = 'Tmn tietueen kirjainkoko on merkityksellinen (\"case sensitive\")';
$string['categories'] = 'Kategoriat';
$string['category'] = 'Kategoria';
$string['categorydeleted'] = 'Kategoria poistettu';
$string['categoryview'] = 'Selaa kategorioiden mukaan';
$string['cnfallowcomments'] = 'Mrit, sallitaanko kommentit sanaston tietueisiin oletuksena';
$string['cnfallowdupentries'] = 'Mrit, sallitaanko pllekkisyydet sanastossa oletuksena';
$string['cnfapprovalstatus'] = 'Mrit oletustila opiskelijoiden lhettmille tietueille.';
$string['cnfcasesensitive'] = 'Onko oletuksena tietueen kirjainkoko merkityksellinen (\"case sensitive\"), kun tietue linkitetn. ';
$string['cnfdefaulthook'] = 'Valitse oletuskokoelma nytettvksi, kun sanastoon tutustutaan ensimmist kertaa.';
$string['cnfdefaultmode'] = 'Valitse oletuskehys, kun sanastoon tutustutaan ensimmist kertaa.';
$string['cnffullmatch'] = 'Kun tietuetta linkitetn, onko oletuksena kohdetekstin kirjainkoko merkityksellinen?';
$string['cnflinkentry'] = 'Linkitetnk tietue automaattisesti oletuksena?';
$string['cnflinkglossaries'] = 'Linkitetnk sanasto automaattisesti oletuksena?';
$string['cnfrelatedview'] = 'Valitse nytttapa automaattiselle linkittmiselle ja tietueen katsomiselle.';
$string['cnfshowgroup'] = 'Nytetnk ryhmerotin?';
$string['cnfsortkey'] = 'Valitse oletuslajitteluavain.';
$string['cnfsortorder'] = 'Valitse oletuslajittelujrjestys.';
$string['cnfstudentcanpost'] = 'Voiko opiskelija list tietueita oletuksena?';
$string['comment'] = 'Kommentti';
$string['commentdeleted'] = 'Kommentti poistettu';
$string['comments'] = 'kommentit';
$string['commentson'] = 'Kommentit thn';
$string['commentupdated'] = 'Kommentti on pivitetty.';
$string['concept'] = 'Ksite';
$string['concepts'] = 'Ksitteet';
$string['configenablerssfeeds'] = 'Tm mahdollistaa RSS sytteiden lhettmisen kaikista sanastoista. Sinun pit viel erikseen kytke sytteet plle jokaisesta sanastosta.';
$string['currentglossary'] = 'Nykyinen sanasto';
$string['dateview'] = 'Selaa pivmrien mukaan';
$string['defaultapproval'] = 'Oletustila hyvksymiselle';
$string['definition'] = 'Mritelm';
$string['definitions'] = 'Mritelmt';
$string['deleteentry'] = 'Poista tietue';
$string['deletingcomment'] = 'Poistetaan kommenttia';
$string['deletingnoneemptycategory'] = 'Tmn kategorian poistaminen ei tuhoa sen sisltmi tietueita - ne merkitn kategorisoimattomiksi.';
$string['descending'] = '(laskeva)';
$string['destination'] = 'Mrnp';
$string['displayformat'] = 'Sanaston tietueiden selaustapa';
$string['displayformatcontinuous'] = 'Jatkuva ilman kirjoittajatietoja';
$string['displayformatdictionary'] = 'Yksinkertainen sanasto tyyli';
$string['displayformatencyclopedia'] = 'Tietosanakirja';
$string['displayformatentrylist'] = 'Tietuelista';
$string['displayformatfaq'] = 'FAQ';
$string['displayformatfullwithauthor'] = 'Tysi kirjoittajan kera';
$string['displayformatfullwithoutauthor'] = 'Tysi ilman kirjoittajaa';
$string['displayformats'] = 'Sanaston tietueiden selaustavat';
$string['displayformatssetup'] = 'Nyttmuodon valinta';
$string['duplicateentry'] = 'Pllekkinen tietue';
$string['editalways'] = 'Muokkaa aina';
$string['editcategories'] = 'Muokkaa kategorioita';
$string['editentry'] = 'Muokkaa tietuetta';
$string['editingcomment'] = 'Muokkaa kommenttia';
$string['entbypage'] = 'Nytettvien tietueiden mr sivua kohti';
$string['entries'] = 'Tietueet';
$string['entrieswithoutcategory'] = 'Kategorisoimattomat tietueet';
$string['entry'] = 'Tietue';
$string['entryalreadyexist'] = 'Tietue on jo olemassa';
$string['entryapproved'] = 'Tm tietue on hyvksytty';
$string['entrydeleted'] = 'Tietue poistettu';
$string['entryexported'] = 'Tietueen vienti onnistui';
$string['entryishidden'] = '(tm tietue on tll hetkell piilotettuna)';
$string['entryleveldefaultsettings'] = 'Tietueiden oletusasetukset';
$string['entrysaved'] = 'Tietue on tallennettu';
$string['entryupdated'] = 'Tietue on pivitetty';
$string['entryusedynalink'] = 'Tm tietue pitisi linkitty automaattisesti';
$string['explainaddentry'] = 'Lis uusi tietue sanastoon.<br />Ksite ja mritelm ovat pakollisia kentti.';
$string['explainall'] = 'Nyt kaikki tietueet yhdell sivulla';
$string['explainalphabet'] = 'Selaa sanastoa tmn hakemiston avulla.';
$string['explainexport'] = 'Vientitiedosto on luotu.<br />Lataa se ja silyt sit huolella. Voit tuoda sen milloin tahansa tlle tai mille tahansa muulle kurssille.';
$string['explainimport'] = 'Mrit tuontitiedosto ja tuonnin asetukset.';
$string['explainspecial'] = 'Nytt tietueet, jotka eivt ala kirjaimella';
$string['exportedentry'] = 'Viety tietue';
$string['exportedfile'] = 'Vientitiedosto';
$string['exportentries'] = 'Vie tietueet';
$string['exportglossary'] = 'Vie sanasto';
$string['exporttomainglossary'] = 'Vie psanastoon';
$string['filetoimport'] = 'Tuontitiedosto';
$string['fillfields'] = 'Ksite ja mritelm ovat pakollisia kentti.';
$string['filtername'] = 'Sanaston automaattinen linkitys';
$string['fullmatch'] = 'Hae vain kokonaisia sanoja';
$string['globalglossary'] = 'Yleinen sanasto';
$string['glossaryleveldefaultsettings'] = 'Sanastojen oletusasetukset';
$string['glossarytype'] = 'Sanaston tyyppi';
$string['glosssaryexported'] = 'Sanasto viety.';
$string['importcategories'] = 'Tuo kategorioita';
$string['importedcategories'] = 'Tuodut kategoriat';
$string['importedentries'] = 'Tuodut tietueet';
$string['importentries'] = 'Tuo tietueita';
$string['isglobal'] = 'Globaali sanasto?';
$string['linkcategory'] = 'Linkit tm kategoria automaattisesti';
$string['mainglossary'] = 'Psanasto';
$string['maxtimehaspassed'] = 'Tmn kommentin ($a) sallittu muokkausaika ylittynyt.';
$string['modulename'] = 'Sanasto';
$string['modulenameplural'] = 'Sanastot';
$string['newentries'] = 'Uudet sanaston tietueet';
$string['newglossary'] = 'Uusi sanasto';
$string['newglossarycreated'] = 'Uusi sanasto luotu.';
$string['newglossaryentries'] = 'Uudet sanaston tietueet:';
$string['nocomment'] = 'Kommentteja ei lytynyt';
$string['nocomments'] = '(Kommentteja ei lytynyt tlle tietueelle)';
$string['noconceptfound'] = 'Ksitett tai mritelm ei lytynyt.';
$string['noentries'] = 'Tst osiossa ei lytynyt tietueita';
$string['noentry'] = 'Hakusanoja ei lytynyt.';
$string['notcategorised'] = 'Kategorisoimaton';
$string['numberofentries'] = 'Hakusanojen lukumr';
$string['onebyline'] = '(yksi rivi kohden)';
$string['printerfriendly'] = 'Tulostukseen soveltuva versio';
$string['question'] = 'Kysymys';
$string['rate'] = 'Arvo';
$string['rating'] = 'Arvio';
$string['ratingeveryone'] = 'Kaikki voivat arvioida tietueita';
$string['ratingno'] = 'Ei arvioita';
$string['ratingonlyteachers'] = 'Vain $a voi arvioida tietueita';
$string['ratings'] = 'Arviot';
$string['ratingssaved'] = 'Arviot tallennettu';
$string['ratingsuse'] = 'Kyt arvioita';
$string['ratingtime'] = 'Rajoita tietueiden arvointi niden pivmrien vlille:';
$string['rejectedentries'] = 'Hyltyt tietueet';
$string['rejectionrpt'] = 'Hylkysraportti';
$string['rsssubscriberss'] = 'Nyt RSS-sytteet $a ';
$string['searchindefinition'] = 'Vapaatekstihaku';
$string['secondaryglossary'] = 'Toissijainen sanasto';
$string['sendinratings'] = 'Lhet viimeisimmt arvioni';
$string['showall'] = 'Nyt \'Kaikki\'';
$string['showalphabet'] = 'Nyt aakkosittain';
$string['showspecial'] = 'Nyt \'Erikoiset\'';
$string['sortby'] = 'Lajittele';
$string['sortbycreation'] = 'Luontipivyksen mukaan';
$string['sortbylastupdate'] = 'Viimeisen pivityksen mukaan';
$string['sortchronogically'] = 'Lajittele kronologisesti';
$string['special'] = 'Erikoiset';
$string['standardview'] = 'Selaa aakkosjrjestyksess';
$string['studentcanpost'] = 'Opiskelijat voivat list tietueita';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['totalentries'] = 'Hakusanojen kokonaismr';
$string['usedynalink'] = 'Linkit sanaston tietueet automaattisesti';
$string['waitingapproval'] = 'Odotetaan hyvksynt';
$string['warningstudentcapost'] = '(Soveltuu vain jos sanasto ei ole psanasto)';
$string['withauthor'] = 'Ksitteet kirjoittajineen';
$string['withoutauthor'] = 'Ksitteet ilman kirjoittajaa';
$string['writtenby'] = 'kirjoittanut';
$string['youarenottheauthor'] = 'Et ole kommentin kirjoittaja, joten et voi muokata sit.';

?>
